<?php

namespace Drupal\fam_dashboard\Cache\Context;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CacheContextInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Create a cache context for a user based on the {user} route parameter.
 *
 * Drupal core only provides the `user` cache context, which is always only
 * the current user. This context adds the ability to select user account
 * from a route as the cache context.
 *
 * Cache context ID: 'route.user'.
 */
class RouteUserCacheContext implements CacheContextInterface {

  /**
   * Create a new cache context for user accounts (by specific user).
   *
   * @param \Drupal\Core\Routing\RouteMatchInterface $routeMatch
   *   A route match object to get parameter and user information from.
   */
  public function __construct(
    protected RouteMatchInterface $routeMatch,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function getLabel(): \Stringable|string {
    return new TranslatableMarkup('User by route parameter');
  }

  /**
   * {@inheritdoc}
   */
  public function getContext(): string {
    $account = $this->routeMatch->getParameter('user');

    if ($account instanceof AccountInterface && $account->isAuthenticated()) {
      return (string) $account->id();
    }

    return 'anonymous';
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata(): CacheableMetadata {
    return new CacheableMetadata();
  }

}
