<?php

namespace Drupal\fam_dashboard\ContextProvider;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\Context\Context;
use Drupal\Core\Plugin\Context\ContextProviderInterface;
use Drupal\Core\Plugin\Context\EntityContext;
use Drupal\Core\Plugin\Context\EntityContextDefinition;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\user\UserInterface;

/**
 * Provides a context for a user entity from the route.
 */
class UserRouteContext implements ContextProviderInterface {

  use StringTranslationTrait;

  /**
   * Entity storage handler for <em>User</em> entities.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected EntityStorageInterface $userStorage;

  /**
   * Constructs an instance of the UserRouteContext class.
   *
   * @param \Drupal\Core\Routing\RouteMatchInterface $routeMatch
   *   The route match object.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager, for discovery and creation of entity type
   *   information, and definitions.
   */
  public function __construct(
    protected RouteMatchInterface $routeMatch,
    EntityTypeManagerInterface $entityTypeManager,
  ) {
    $this->userStorage = $entityTypeManager->getStorage('user');
  }

  /**
   * {@inheritdoc}
   */
  public function getRuntimeContexts(array $unqualified_context_ids): array {
    $value = NULL;

    if ($account = $this->routeMatch->getParameter('user')) {
      if ($account instanceof AccountInterface && !($account instanceof UserInterface)) {
        $account = $this->userStorage->load($account->id());
      }

      $value = $account;
    }

    $cacheability = new CacheableMetadata();
    $cacheability->setCacheContexts(['route.user']);
    $contextDef = EntityContextDefinition::fromEntityTypeId('user')
      ->setLabel($this->t('User from route'))
      ->setRequired(FALSE);

    $context = new Context($contextDef, $value);
    $context->addCacheableDependency($cacheability);

    return ['user' => $context];
  }

  /**
   * {@inheritdoc}
   */
  public function getAvailableContexts(): array {
    $context = EntityContext::fromEntityTypeId('user', $this->t('User from route'));
    return ['user' => $context];
  }

}
