<?php

namespace Drupal\fam_registration\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Deriver to conditionally provide account menu items based on FAM settings.
 */
class AccountMenuItems extends DeriverBase implements ContainerDeriverInterface {

  /**
   * Creates a new instance of the AccountMenuItems deriver.
   *
   * @param string $basePluginId
   *   The base plugin ID.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory service.
   */
  public function __construct(
    protected string $basePluginId,
    protected ConfigFactoryInterface $configFactory,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $basePluginId) {
    return new static(
      $basePluginId,
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $settings = $this->configFactory->get('fam_registration.settings');

    $links = [];
    if ($settings->get('menu_register_enable')) {
      $links['register'] = [
        'title' => $settings->get('menu_register_text') ?: new TranslatableMarkup('Register'),
        'route_name' => 'user.register',
        'weight' => -10,
      ] + $base_plugin_definition;
    }

    return $links;
  }

}
