<?php

namespace Drupal\fam_registration\Plugin;

use Drupal\Component\Plugin\FallbackPluginManagerInterface;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;

/**
 * Plugin manager for registration welcome page content builders.
 */
class WelcomePluginManager extends DefaultPluginmanager implements FallbackPluginManagerInterface {

  /**
   * Constructs a registration welcome plugin manager.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache, ModuleHandlerInterface $module_handler) {
    parent::__construct(
      'Plugin/FamWelcome',
      $namespaces,
      $module_handler,
      'Drupal\fam_registration\Plugin\WelcomeInterface',
      'Drupal\fam_registration\Attribute\FamWelcome'
    );

    $this->alterInfo('fam_registration_welcome');
    $this->setCacheBackend($cache, 'fam_registration_welcome');
  }

  /**
   * {@inheritdoc}
   */
  public function getFallbackPluginId($plugin_id, array $configuration = []): string {
    return 'message';
  }

}
