<?php

namespace Drupal\fam\Controller;

use Drupal\user\Controller\UserController;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Route controller for overriding the password reset login redirect.
 */
class PasswordResetController extends UserController {

  /**
   * {@inheritdoc}
   */
  public function resetPassLogin($uid, $timestamp, $hash, Request $request) {
    $response = parent::resetPassLogin($uid, $timestamp, $hash, $request);
    $currentUser = $this->currentUser();

    // Check if the user has been logged in after calling the parent
    // UserController::resetPassLogin() method, as this should mean that the
    // one-time user login tokens have validated.
    //
    // We want to alter the redirect destination relying on as little of the
    // reset token handling as possible. This makes it less likely that this
    // password reset override will need to be updated if Drupal core needs
    // to change this process in the future (or if a vulnerability is found).
    if ($uid === $currentUser->id() && $currentUser->isAuthenticated()) {
      $urlOpts = ['absolute' => TRUE];

      // Attempt to keep the original query parameters from the original
      // reset URL, to keep closest to the original token handling from Core.
      if ($response instanceof RedirectResponse) {
        $targetUrl = $response->getTargetUrl();

        if ($query = parse_url($targetUrl, PHP_URL_QUERY)) {
          $urlOpts['query'] = [];
          parse_str($query, $urlOpts['query']);
        }
      }

      // Fallback token using the known reset method at the time of writing.
      if (empty($urlOpts['query']['pass-reset-token'])) {
        if ($token = $request->getSession()->get('pass_reset_' . $uid)) {
          $urlOpts['query']['pass-reset-token'] = $token;
        }
        else {
          // Without a reset token, we cannot provide a valid reset link.
          return $response;
        }
      }

      // Recreate the redirect using the FAM provided password reset route.
      $response = $this->redirect(
        'fam.user.edit_pass',
        ['user' => $uid],
        $urlOpts
      );
    }

    return $response;
  }

}
