<?php

namespace Drupal\fam\Event;

use Drupal\Component\EventDispatcher\Event;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Event class for password reset actions event.
 */
class PassResetActionsEvent extends Event {

  /**
   * Creates a new instance of the PassResetActionsEvent event.
   *
   * @param array $actions
   *   Reference to the form action elements (form elements).
   * @param array $form
   *   The form elements and structures.
   * @param \Drupal\Core\Form\FormStateInterface $formState
   *   The form state and build info of the form.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The account of the user that the actions are being calculated for.
   */
  public function __construct(
    protected array &$actions,
    protected array $form,
    protected FormStateInterface $formState,
    protected AccountInterface $account,
  ) {
  }

  /**
   * Get a reference to the form action elements.
   *
   * @return array
   *   A reference to the form actions.
   */
  public function &getActions(): array {
    return $this->actions;
  }

  /**
   * Get the form elements and structure for the edit form.
   *
   * @return array
   *   Get the form elements and structures.
   */
  public function getForm(): array {
    return $this->form;
  }

  /**
   * Get the form state instance.
   *
   * @return \Drupal\Core\Form\FormStateInterface
   *   The form state and build information.
   */
  public function getFormState(): FormStateInterface {
    return $this->formState;
  }

  /**
   * The user that the password reset actions are being built for.
   *
   * @return \Drupal\Core\Session\AccountInterface
   *   Get the account session for the user the actions are being built for.
   */
  public function getAccount(): AccountInterface {
    return $this->account;
  }

}
