<?php

namespace Drupal\fam\Form\Alter;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A login form alter to apply FAM options to the form.
 */
class LoginFormAlter implements ContainerInjectionInterface {


  /**
   * The FAM module settings.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected ImmutableConfig $famSettings;

  /**
   * Creates a new instance of the LoginFormAlter class.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory service.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler.
   */
  public function __construct(
    protected ConfigFactoryInterface $configFactory,
    protected ModuleHandlerInterface $moduleHandler,
  ) {
    $this->famSettings = $configFactory->get('fam.settings');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('config.factory'),
      $container->get('module_handler'),
    );
  }

  /**
   * Alter the login form to include links to send password or username reset.
   *
   * @param array $form
   *   Reference to the login form being altered.
   * @param \Drupal\Core\Form\FormStateInterface $formState
   *   The form state and build info.
   */
  public function alterForm(array &$form, FormStateInterface $formState): void {
    $loginSettings = $this->famSettings->get('login_form') ?: [];

    if (!empty($loginSettings['password_link'])) {
      $passwordLink = Url::fromRoute('user.pass');
      $description = new TranslatableMarkup('<a href=":reset_pass_url">Forgot your password?</a>', [
        ':reset_pass_url' => $passwordLink->toString(),
      ]);

      $form['pass']['#description'] = $form['pass']['#description'] ?? [];

      if (is_string($form['pass']['#description']) || $form['pass']['#description'] instanceof \Stringable) {
        $form['pass']['#description'] = new FormattableMarkup(':description <p>@reset_link</p>', [
          ':description' => $form['pass']['#description'],
          '@reset_link' => $description,
        ]);
      }
      elseif (is_array($form['pass']['#description'])) {
        $form['pass']['#description'][] = ['#markup' => $description];
      }
    }
  }

}
