<?php

namespace Drupal\fam\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * The form dedicated change email form.
 *
 * Form is used for editing account emails when the "fam.settings::email_form"
 * config option is set as enabled.
 */
class EditEmailForm extends EditUserFieldForm {

  /**
   * {@inheritdoc}
   */
  protected static function getFormOperation(): string {
    return 'edit_email';
  }

  /**
   * {@inheritdoc}
   */
  protected static function getEditFields(): array {
    return ['mail'];
  }

  /**
   * {@inheritdoc}
   */
  protected function buildFieldElements(array &$form, FormStateInterface $form_state): array {
    $elements = [];
    /** @var \Drupal\user\UserInterface $account */
    $account = $this->getEntity();

    if ($account->id() == $this->currentUser->id()) {
      $elements['current_pass'] = $this->buildCurrentPass($form_state);
      $elements['current_pass']['#description'] = $this->t('Required if you want to change the email information below. <a href=":request_new_url" title="Send password reset instructions via email.">Reset your password</a>.', [
        ':request_new_url' => Url::fromRoute('user.pass')->toString(),
      ]);
    }

    $elements['mail'] = [
      '#type' => 'email',
      '#title' => $this->t('Email address'),
      '#description' => $this->t('A valid email address. All emails from the system will be sent to this address. The email address is not made public and will only be used if you wish to receive a new password or wish to receive certain news or notifications by email.'),
      '#required' => TRUE,
      '#default_value' => ($account->getEmail() ?: ''),
    ];

    return $elements;
  }

}
