<?php

namespace Drupal\fam;

use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * The helper for load and apply settings for the user account settings form.
 */
class UserFieldHelper {

  const FIELD_EDIT_ACCOUNT_FORM = 0;
  const FIELD_EDIT_SEPARATE_FORM = 1;
  const FIELD_EDIT_DISABLED = 2;

  /**
   * Maps the field to the configuration value that controls it.
   *
   * @var string[]
   */
  protected readonly array $configMap;

  /**
   * The FAM module settings.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected ImmutableConfig $settings;

  /**
   * Authentication handler plugin configurations.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected ImmutableConfig $pluginConfig;

  /**
   * Creates a new instance of the UserFieldHelper class.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory service.
   * @param \Drupal\Component\Plugin\PluginManagerInterface $authManager
   *   Authentication plugin manager.
   */
  public function __construct(
    ConfigFactoryInterface $configFactory,
    protected PluginManagerInterface $authManager,
  ) {
    $this->configMap = [
      'pass' => 'password_form',
      'mail' => 'email_form',
    ];

    $this->settings = $configFactory->get('fam.settings');
    $this->pluginConfig = $configFactory->get('fam.account_auth_handlers');
  }

  /**
   * Get available options for the user account edit fields.
   *
   * @return array<int,\Stringable|string>
   *   The list of available option for the user edit settings.
   */
  public static function getFieldEditOptions(): array {
    return [
      self::FIELD_EDIT_ACCOUNT_FORM => new TranslatableMarkup('On user profile form'),
      self::FIELD_EDIT_SEPARATE_FORM => new TranslatableMarkup('On separate individual form'),
      self::FIELD_EDIT_DISABLED => new TranslatableMarkup('Disable editing'),
    ];
  }

}
